# Acceptance Report: REQ-NNN

## Requirement: [title]

## Acceptance Criteria

| # | Criterion | Code | Test | Real outcome | Verdict |
|---|-----------|------|------|-------------|---------|
| 1 | [text from REQ] | file.py:NN | test_file.py:NN | YES/NO | PASS/FAIL |
| 2 | [text from REQ] | — | — | — | FAIL: [reason] |

## Test Completeness

| File | Unit | Edge | Integration | Error paths | Coverage |
|------|------|------|-------------|-------------|----------|
| module.py | Y/N | Y/N | Y/N | Y/N | NN% |

## Gaps

1. [specific gap — what is missing or incorrect]
2. [specific gap]

## Verdict: PASS / FAIL

<!-- If FAIL: save as .ievo/reports/acceptance/ACC-REQ-NNN.md -->
<!-- If FAIL on revision: save as ACC-REQ-NNN-rN.md -->
<!-- If PASS: set requirement status to "implemented" in SPEC_INDEX.md -->
